@@ -26,7 +26,7 @@
  *****************************************************************************/
 
 #include <errno.h>
-#include <projects.h>
+#include "projects.h"
 #include <string.h>
 
 /* SEC_TO_RAD = Pi/180/3600 */
