@@ -30,12 +30,12 @@
 
 
 #define PJ_LIB__
-#include <geodesic.h>
+#include "geodesic.h"
 #include <stdio.h>
 #include <string.h>
 #include <errno.h>
 #include <ctype.h>
-#include <proj.h>
+#include "proj.h"
 #include "proj_internal.h"
 #include "projects.h"
 
@@ -470,7 +470,7 @@ pj_init(int argc, char **argv) {
 }
 
 
-static PJ_CONSTRUCTOR pj_locate_constructor (const char *name) {
+static PJ_CONSTRUCTOR locate_constructor (const char *name) {
     int i;
     char *s;
     for (i = 0; (s = pj_list[i].id) && strcmp(name, s) ; ++i) ;
@@ -557,7 +557,7 @@ pj_init_ctx(projCtx ctx, int argc, char **argv) {
         return pj_dealloc_params (ctx, start, PJD_ERR_PROJ_NOT_NAMED);
     name += 5;
 
-    proj = pj_locate_constructor (name);
+    proj = locate_constructor (name);
     if (0==proj)
         return pj_dealloc_params (ctx, start, PJD_ERR_UNKNOWN_PROJECTION_ID);
 
@@ -587,9 +587,12 @@ pj_init_ctx(projCtx ctx, int argc, char **argv) {
     PIN->vgridlist_geoid = NULL;
     PIN->vgridlist_geoid_count = 0;
 
-    /* Set datum parameters */
-    if (pj_datum_set(ctx, start, PIN))
-        return pj_default_destructor (PIN, proj_errno(PIN));
+    /* Set datum parameters. Similarly to +init parameters we want to expand    */
+    /* +datum parameters as late as possible when dealing with pipelines.       */
+    /* otherwise only the first occurrence of +datum will be expanded and that */
+    if (n_pipelines == 0)
+        if (pj_datum_set(ctx, start, PIN))
+            return pj_default_destructor (PIN, proj_errno(PIN));
 
     err = pj_ellipsoid (PIN);
 
