@@ -12,18 +12,22 @@ PROJ_HEAD(aitoff, "Aitoff")
 PROJ_HEAD(alsk, "Mod. Stererographics of Alaska")
 PROJ_HEAD(apian, "Apian Globular I")
 PROJ_HEAD(august, "August Epicycloidal")
+PROJ_HEAD(axisswap, "Axis ordering")
 PROJ_HEAD(bacon, "Bacon Globular")
 PROJ_HEAD(bipc, "Bipolar conic of western hemisphere")
 PROJ_HEAD(boggs, "Boggs Eumorphic")
 PROJ_HEAD(bonne, "Bonne (Werner lat_1=90)")
 PROJ_HEAD(calcofi, "Cal Coop Ocean Fish Invest Lines/Stations")
+PROJ_HEAD(cart,    "Geodetic/cartesian conversions")
 PROJ_HEAD(cass, "Cassini")
 PROJ_HEAD(cc, "Central Cylindrical")
+PROJ_HEAD(ccon, "Central Conic")
 PROJ_HEAD(cea, "Equal Area Cylindrical")
 PROJ_HEAD(chamb, "Chamberlin Trimetric")
 PROJ_HEAD(collg, "Collignon")
 PROJ_HEAD(comill, "Compact Miller")
 PROJ_HEAD(crast, "Craster Parabolic (Putnins P4)")
+PROJ_HEAD(deformation, "Kinematic grid shift")
 PROJ_HEAD(denoy, "Denoyer Semi-Elliptical")
 PROJ_HEAD(eck1, "Eckert I")
 PROJ_HEAD(eck2, "Eckert II")
@@ -39,6 +43,7 @@ PROJ_HEAD(fahey, "Fahey")
 PROJ_HEAD(fouc, "Foucaut")
 PROJ_HEAD(fouc_s, "Foucaut Sinusoidal")
 PROJ_HEAD(gall, "Gall (Gall Stereographic)")
+PROJ_HEAD(geoc, "Geocentric Latitude")
 PROJ_HEAD(geocent, "Geocentric")
 PROJ_HEAD(geos, "Geostationary Satellite View")
 PROJ_HEAD(gins8, "Ginsburg VIII (TsNIIGAiK)")
@@ -51,8 +56,11 @@ PROJ_HEAD(hammer, "Hammer & Eckert-Greifendorff")
 PROJ_HEAD(hatano, "Hatano Asymmetrical Equal Area")
 PROJ_HEAD(healpix, "HEALPix")
 PROJ_HEAD(rhealpix, "rHEALPix")
+PROJ_HEAD(helmert,   "3- and 7-parameter Helmert shift")
+PROJ_HEAD(hgridshift, "Horizontal grid shift")
+PROJ_HEAD(horner,    "Horner polynomial evaluation")
 PROJ_HEAD(igh,  "Interrupted Goode Homolosine")
-PROJ_HEAD(imw_p, "Internation Map of the World Polyconic")
+PROJ_HEAD(imw_p, "International Map of the World Polyconic")
 PROJ_HEAD(isea, "Icosahedral Snyder Equal Area")
 PROJ_HEAD(kav5, "Kavraisky V")
 PROJ_HEAD(kav7, "Kavraisky VII")
@@ -82,6 +90,7 @@ PROJ_HEAD(mil_os, "Miller Oblated Stereographic")
 PROJ_HEAD(mill, "Miller Cylindrical")
 PROJ_HEAD(misrsom, "Space oblique for MISR")
 PROJ_HEAD(moll, "Mollweide")
+PROJ_HEAD(molodensky, "Molodensky transform")
 PROJ_HEAD(murd1, "Murdoch I")
 PROJ_HEAD(murd2, "Murdoch II")
 PROJ_HEAD(murd3, "Murdoch III")
@@ -100,6 +109,7 @@ PROJ_HEAD(ortel, "Ortelius Oval")
 PROJ_HEAD(ortho, "Orthographic")
 PROJ_HEAD(pconic, "Perspective Conic")
 PROJ_HEAD(patterson, "Patterson Cylindrical")
+PROJ_HEAD(pipeline, "Transformation pipeline manager")
 PROJ_HEAD(poly, "Polyconic (American)")
 PROJ_HEAD(putp1, "Putnins P1")
 PROJ_HEAD(putp2, "Putnins P2")
@@ -128,6 +138,7 @@ PROJ_HEAD(tissot, "Tissot Conic")
 PROJ_HEAD(tmerc, "Transverse Mercator")
 PROJ_HEAD(tpeqd, "Two Point Equidistant")
 PROJ_HEAD(tpers, "Tilted perspective")
+PROJ_HEAD(unitconvert, "Unit conversion")
 PROJ_HEAD(ups, "Universal Polar Stereographic")
 PROJ_HEAD(urm5, "Urmaev V")
 PROJ_HEAD(urmfps, "Urmaev Flat-Polar Sinusoidal")
@@ -137,6 +148,7 @@ PROJ_HEAD(vandg2, "van der Grinten II")
 PROJ_HEAD(vandg3, "van der Grinten III")
 PROJ_HEAD(vandg4, "van der Grinten IV")
 PROJ_HEAD(vitk1, "Vitkovsky I")
+PROJ_HEAD(vgridshift, "Vertical grid shift")
 PROJ_HEAD(wag1, "Wagner I (Kavraisky VI)")
 PROJ_HEAD(wag2, "Wagner II")
 PROJ_HEAD(wag3, "Wagner III")
