@@ -25,7 +25,7 @@
 */
 #define PJ_LIB__
 #include <errno.h>
-#include <proj.h>
+#include "proj.h"
 #include "projects.h"
 
 struct pj_opaque {
